@@ -6,6 +6,7 @@ import hildon, osso
 import traceback
 import time
 import thread
+import contactview
 from hermes import Hermes
 
 gobject.threads_init()
@@ -41,13 +42,61 @@ class HermesGUI:
                       facebook = self.get_use_facebook())
         fb2c.load_friends()
         fb2c.sync_contacts(resync = force)
-        gobject.idle_add(hildon.hildon_banner_show_information, self.window, '', "Updated %d contacts" % (len(fb2c.updated)))
-        gobject.idle_add(self.window.set_property, 'sensitive', True)
+        gobject.idle_add(self.open_summary, fb2c)
       except Exception, e:
         traceback.print_exc()
         gobject.idle_add(self.report_error, 'Something went wrong: ' + e.message)
 
 
+  # -----------------------------------------------------------------------
+  def open_summary(self, fb2c):
+    gobject.idle_add(self.window.set_property, 'sensitive', True)
+
+    dialog = gtk.Dialog('Summary', self.window)
+    dialog.add_button('Done', gtk.RESPONSE_OK)
+    
+    button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,
+                           title = 'Updated %d contacts' % (len(fb2c.updated)))
+    button.connect('clicked', self.show_contacts, fb2c.updated)
+    button.set_property('sensitive', len(fb2c.updated) > 0)
+    dialog.vbox.add(button)
+    
+    button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,
+                           title = 'Matched %d contacts' % (len(fb2c.matched)))
+    button.connect('clicked', self.show_contacts, fb2c.matched)
+    button.set_property('sensitive', len(fb2c.matched) > 0)
+    dialog.vbox.add(button)
+    
+    button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,
+                           title = '%d contacts unmatched' % (len(fb2c.unmatched)))
+    button.connect('clicked', self.show_contacts, fb2c.unmatched)
+    button.set_property('sensitive', len(fb2c.unmatched) > 0)
+    dialog.vbox.add(button)
+    
+    dialog.show_all()
+    dialog.run()
+    dialog.hide()
+  
+
+  # -----------------------------------------------------------------------
+  def show_contacts(self, widget, contacts):
+    view = contactview.ContactView(contacts)
+
+    dialog = gtk.Dialog('Contacts', self.window)
+    dialog.add_button('Back', gtk.RESPONSE_OK)
+    #view.connect('contact-activated', self.map_contact)
+    dialog.vbox.add(view)
+    dialog.show_all()
+    
+    dialog.run()
+    dialog.hide()
+    
+    
+  # -----------------------------------------------------------------------
+  def map_contact(self, widget, contact):
+    print widget, contact
+
+
   # -----------------------------------------------------------------------
   def open_prefs(self, widget = None):
     dialog = gtk.Dialog('Accounts', self.window)
@@ -167,7 +216,7 @@ class HermesGUI:
     self.app = hildon.Program()
     self.window = hildon.Window()
     gtk.set_application_name('Hermes')
-    osso_context = osso.Context('org.maemo.hermes', '0.0.2', False)
+    self.osso_context = osso.Context('org.maemo.hermes', '0.0.3', False)
     self.app.add_window(self.window)
 
     self.window.connect("delete-event", gtk.main_quit)
